###################################################
### chunk number 1: setup
###################################################
options(width=75)


###################################################
### chunk number 2: mantel1
###################################################
# load the ecodist package
library(ecodist)
# make sure that each repetition gives the same results
set.seed(9876) 

# generate sample data
sampleloc <- 1:20
species <- matrix(rnorm(100), nrow=20, ncol=5)
# calculate dissimilarities
sampleloc.edist <- distance(sampleloc, "euclidean")
species.bcdist <- distance(species, "bray-curtis")
# simple Mantel test
mantel(species.bcdist ~ sampleloc.edist)


###################################################
### chunk number 3: mantel2
###################################################
# ranked Mantel test
mantel(species.bcdist ~ sampleloc.edist, mrank=TRUE)


###################################################
### chunk number 4: fig1plot
###################################################
# reproduce Figure 1
# read in the simulation results
data(permresults)
# choose the sample size to examine, here n=50
# simulations cover n = 10, 25, 50, 100
plotdata <- permresults[permresults$n == 50, ]
par(mfcol=c(3,2))
par(mai=c(.2, .2, .2, .2))
par(oma=c(4,4,0,0))
boxplot(plotdata[,3] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "a. 500 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,6] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "b. 1,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,9] ~ plotdata[,2], ylim=c(0, .5), xlab="Mantel r", ylab="")
abline(h=0.05)
text(3.4, .45, "c. 10,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,12] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "d. 100,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,15] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "e. 1,000,000 permutations", cex=1.2, pos=2, offset=0)
mtext("Mantel r", side = 2, line=1, outer=TRUE, cex=1.3)
mtext("p-value", side = 1, line=1, outer=TRUE, cex=1.3)


###################################################
### chunk number 5: fig1
###################################################
# reproduce Figure 1
# read in the simulation results
data(permresults)
# choose the sample size to examine, here n=50
# simulations cover n = 10, 25, 50, 100
plotdata <- permresults[permresults$n == 50, ]
par(mfcol=c(3,2))
par(mai=c(.2, .2, .2, .2))
par(oma=c(4,4,0,0))
boxplot(plotdata[,3] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "a. 500 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,6] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "b. 1,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,9] ~ plotdata[,2], ylim=c(0, .5), xlab="Mantel r", ylab="")
abline(h=0.05)
text(3.4, .45, "c. 10,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,12] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "d. 100,000 permutations", cex=1.2, pos=2, offset=0)
boxplot(plotdata[,15] ~ plotdata[,2], ylim=c(0, .5), xlab="", ylab="")
abline(h=0.05)
text(3.4, .45, "e. 1,000,000 permutations", cex=1.2, pos=2, offset=0)
mtext("Mantel r", side = 2, line=1, outer=TRUE, cex=1.3)
mtext("p-value", side = 1, line=1, outer=TRUE, cex=1.3)


###################################################
### chunk number 6: mantel3
###################################################
# partial Mantel test, with a third data component
soil <- runif(20)
soil.edist <- distance(soil, "euclidean")
mantel(species.bcdist ~ sampleloc.edist + soil.edist)
mantel(species.bcdist ~ soil.edist + sampleloc.edist)


###################################################
### chunk number 7: fig2plot
###################################################
# Figure 2
# import the data
data(bump)
# draw the image
par(mfrow=c(1,1))
par(mai=c(.2, .2, .2, .2))
image(bump, col=gray(seq(0.2, 1, by=.2)))


###################################################
### chunk number 8: fig2
###################################################
# Figure 2
# import the data
data(bump)
# draw the image
par(mfrow=c(1,1))
par(mai=c(.2, .2, .2, .2))
image(bump, col=gray(seq(0.2, 1, by=.2)))


###################################################
### chunk number 9: fig3plot
###################################################
# Figure 3
# create the spatial coordinates
X <- col(bump)
Y <- row(bump)
# calculate dissimilarities for data and space
geo.dist <- distance(cbind(as.vector(X), as.vector(Y)), "euclidean")
value.dist <- distance(as.vector(bump), "euclidean")
# calculate and plot the piecewise Mantel correlogram
bump.pmgram <- pmgram(value.dist, geo.dist)
plot(bump.pmgram)


###################################################
### chunk number 10: fig3
###################################################
# Figure 3
# create the spatial coordinates
X <- col(bump)
Y <- row(bump)
# calculate dissimilarities for data and space
geo.dist <- distance(cbind(as.vector(X), as.vector(Y)), "euclidean")
value.dist <- distance(as.vector(bump), "euclidean")
# calculate and plot the piecewise Mantel correlogram
bump.pmgram <- pmgram(value.dist, geo.dist)
plot(bump.pmgram)


###################################################
### chunk number 11: example1
###################################################
# import the data
data(graze)
# calculate dissimilarities
graze.bcdist <- distance(graze[,3:ncol(graze)], "bray-curtis")
sitelocation.edist <- distance(graze$sitelocation, "euclidean")
forestpct.edist <- distance(graze$forestpct, "euclidean")


###################################################
### chunk number 12: example2
###################################################
# simple and partial Mantel tests
mantel(graze.bcdist ~ forestpct.edist, nperm=10000)[c("mantelr", "pval1")]
mantel(graze.bcdist ~ sitelocation.edist, nperm=10000)[c("mantelr", "pval1")]
mantel(forestpct.edist ~ sitelocation.edist, nperm=10000)[c("mantelr", "pval1")]
mantel(graze.bcdist ~ forestpct.edist + sitelocation.edist, 
nperm=10000)[c("mantelr", "pval1")]


###################################################
### chunk number 13: fig4plot
###################################################
# Figure 4
# calculate correlograms for vegetation and for forest cover
vegetation.pmgram <- pmgram(graze.bcdist, sitelocation.edist, nperm=10000, nclass=6)
forest.pmgram <- pmgram(forestpct.edist, sitelocation.edist, nperm=10000, nclass=6) 
par(mfrow=c(2,1))
# figure 4a
plot(vegetation.pmgram, main="a. Plant community composition")
# figure 4b
plot(forest.pmgram, main="b. Surrounding forest cover")


###################################################
### chunk number 14: fig4
###################################################
# Figure 4
# calculate correlograms for vegetation and for forest cover
vegetation.pmgram <- pmgram(graze.bcdist, sitelocation.edist, nperm=10000, nclass=6)
forest.pmgram <- pmgram(forestpct.edist, sitelocation.edist, nperm=10000, nclass=6) 
par(mfrow=c(2,1))
# figure 4a
plot(vegetation.pmgram, main="a. Plant community composition")
# figure 4b
plot(forest.pmgram, main="b. Surrounding forest cover")


###################################################
### chunk number 15: fig5plot
###################################################
# Figure 5
# compare linear regression and piecewise spatial detrending
forest.resids <- residuals(lm(as.vector(forestpct.edist) ~ as.vector(sitelocation.edist)))
forest.resids.pmgram <- pmgram(forest.resids, sitelocation.edist, nperm=10000, nclass=6)

# Figure 5a
par(mfrow=c(2,1))
plot(forest.resids.pmgram, main="a. Forest cover: Residuals")

# Take the piecewise (detrended) residuals for forest, then look at their patterning.
forest.presids <- residuals(pmgram(forestpct.edist, sitelocation.edist, resids=TRUE, nclass=6))
forest.presids.pmgram <- pmgram(forest.presids, sitelocation.edist, nperm=10000, nclass=6)
# Figure 5b
plot(forest.presids.pmgram, main="b. Forest cover: Piecewise residuals", ylim=range(forest.resids.pmgram$mgram[,"piecer"]))


###################################################
### chunk number 16: fig5
###################################################
# Figure 5
# compare linear regression and piecewise spatial detrending
forest.resids <- residuals(lm(as.vector(forestpct.edist) ~ as.vector(sitelocation.edist)))
forest.resids.pmgram <- pmgram(forest.resids, sitelocation.edist, nperm=10000, nclass=6)

# Figure 5a
par(mfrow=c(2,1))
plot(forest.resids.pmgram, main="a. Forest cover: Residuals")

# Take the piecewise (detrended) residuals for forest, then look at their patterning.
forest.presids <- residuals(pmgram(forestpct.edist, sitelocation.edist, resids=TRUE, nclass=6))
forest.presids.pmgram <- pmgram(forest.presids, sitelocation.edist, nperm=10000, nclass=6)
# Figure 5b
plot(forest.presids.pmgram, main="b. Forest cover: Piecewise residuals", ylim=range(forest.resids.pmgram$mgram[,"piecer"]))


###################################################
### chunk number 17: fig6plot
###################################################
# Figure 6
combined.pmgram <- pmgram(graze.bcdist, sitelocation.edist, partial=forestpct.edist, nperm=10000)
plot(combined.pmgram, main="a. Composition vs forest given space", xlab="Difference in Forest Cover")
vegetation.presids <- residuals(pmgram(graze.bcdist, sitelocation.edist, resids=TRUE, nclass=6))


###################################################
### chunk number 18: fig6test
###################################################
mantel(vegetation.presids ~ forest.presids, nperm=10000, nboot=0)[c("mantelr", "pval1")]


###################################################
### chunk number 19: fig6
###################################################
# Figure 6
combined.pmgram <- pmgram(graze.bcdist, sitelocation.edist, partial=forestpct.edist, nperm=10000)
plot(combined.pmgram, main="a. Composition vs forest given space", xlab="Difference in Forest Cover")
vegetation.presids <- residuals(pmgram(graze.bcdist, sitelocation.edist, resids=TRUE, nclass=6))


